@@ -4,20 +4,24 @@ class FencesException(Exception):
     """
     pass
 
+
 class ResolveReferenceException(FencesException):
     """
     Thrown by Node.resolve()
     """
+
     def __init__(self, message: str, node_id: str) -> None:
         super().__init__(message)
         self.node_id = node_id
 
+
 class ParseException(FencesException):
     """
     Base class for all exceptions occurring during schema parsing
     """
     pass
 
+
 class InternalException(FencesException):
     """
     Raised if fences reaches an invalid internal state.
@@ -25,7 +29,17 @@ class InternalException(FencesException):
     """
     pass
 
+
 class ConfigException(FencesException):
     """
     All config related exceptions
-    """
\ No newline at end of file
+    """
+    pass
+
+
+class NormalizationException(FencesException):
+    pass
+
+
+class JsonPointerException(FencesException):
+    pass
